# Generated by roxygen2: do not edit by hand

S3method("dimnames<-",koma_ts)
S3method(Ops,koma_ts)
S3method(acf_plot,koma_estimate)
S3method(as.ts,koma_ts)
S3method(as.ts,list)
S3method(as_list,list)
S3method(as_list,mts)
S3method(as_mets,list)
S3method(concat,list)
S3method(concat,mts)
S3method(concat,ts)
S3method(cumprod,koma_ts)
S3method(cumsum,koma_ts)
S3method(dates_to_num,"NULL")
S3method(dates_to_num,double)
S3method(dates_to_num,list)
S3method(dates_to_str,"NULL")
S3method(dates_to_str,Date)
S3method(dates_to_str,POSIXct)
S3method(dates_to_str,double)
S3method(dates_to_str,list)
S3method(diff,koma_ts)
S3method(estimate,list)
S3method(filter_by_attribute,list)
S3method(filter_by_attribute,mts)
S3method(forecast,koma_estimate)
S3method(format,koma_estimate)
S3method(format,koma_forecast)
S3method(format,koma_seq)
S3method(format,koma_ts)
S3method(hdi,default)
S3method(hdi,koma_estimate)
S3method(hdi,koma_forecast)
S3method(hdr,default)
S3method(hdr,koma_estimate)
S3method(hdr,koma_forecast)
S3method(lag,koma_ts)
S3method(level,list)
S3method(level,mts)
S3method(level,ts)
S3method(na.omit,koma_ts)
S3method(num_to_dates,"NULL")
S3method(num_to_dates,double)
S3method(num_to_dates,list)
S3method(plot,koma_estimate_hdr)
S3method(plot,koma_forecast)
S3method(print,koma_estimate)
S3method(print,koma_forecast)
S3method(print,koma_hdi)
S3method(print,koma_hdr)
S3method(print,koma_seq)
S3method(print,koma_summary)
S3method(print,koma_texreg)
S3method(print,koma_ts)
S3method(rate,list)
S3method(rate,mts)
S3method(rate,ts)
S3method(rebase,list)
S3method(rebase,mts)
S3method(rebase,ts)
S3method(running_mean,koma_estimate)
S3method(running_mean_plot,koma_estimate)
S3method(summary,koma_estimate)
S3method(summary,koma_estimate_hdi)
S3method(summary,koma_estimate_hdr)
S3method(summary,koma_forecast)
S3method(summary,koma_forecast_hdi)
S3method(summary,koma_forecast_hdr)
S3method(summary,koma_hdi)
S3method(summary,koma_hdr)
S3method(ta,koma_ts)
S3method(trace_plot,koma_estimate)
S3method(window,koma_ts)
export(acf_plot)
export(as_ets)
export(as_list)
export(as_mets)
export(concat)
export(estimate)
export(ets)
export(extract.koma_estimate)
export(filter_by_attribute)
export(forecast)
export(generate_sample_data)
export(hdi)
export(hdr)
export(init_koma_theme)
export(is_ets)
export(is_system_of_equations)
export(level)
export(model_evaluation)
export(model_identification)
export(rate)
export(rebase)
export(running_mean)
export(running_mean_plot)
export(system_of_equations)
export(trace_plot)
importFrom(stats,as.ts)
importFrom(stats,dnorm)
importFrom(stats,is.mts)
importFrom(stats,is.ts)
importFrom(stats,lag)
importFrom(stats,na.omit)
importFrom(stats,rnorm)
importFrom(stats,window)
importFrom(tempdisagg,ta)
